"use strict";

/**
 * Accessibility implementation decisions for this widget were based, in part, on the following:
 * - General rules of ARIA use: http://w3c.github.io/aria-in-html/
 * - Using default implicit ARIA semantics is preferable to adding redundant roles, etc.:
 *   https://www.w3.org/TR/html-aria/
 * - Using "aria-expanded" for collapsible elements:
 *   https://www.w3.org/WAI/GL/wiki/Using_aria-expanded_to_indicate_the_state_of_a_collapsible_element
 * - I studied the mobile nav menu at https://www.paciellogroup.com/
 */

const buttonClass = "js-c-related-articles__more";
const drawerClass = "js-c-related-articles__drawer";

function init(domElement) {
  this.element = domElement;
  this.button = this.element.getElementsByClassName(buttonClass).item(0);
  this.drawer = this.element.getElementsByClassName(drawerClass).item(0);

  if (this.button && this.drawer) {
    this.button.addEventListener("click", () => {
      open.call(this);
    });
    this.button.addEventListener("touchend", () => {
      open.call(this);
    });
  }
}

function open() {
  if (this.button.getAttribute("aria-expanded") === "false" && !this.drawer.classList.contains(`${drawerClass}--open`)) {
    this.button.setAttribute("aria-expanded", true);
    // TODO: Should this be "u-visually-hidden"? Do blind users even
    // care to know that this button exists in the first place?
    // this.button.classList.add("u-hidden");
    this.drawer.classList.add(`${drawerClass}--open`);
    // TODO: Maybe we shouldn't use the "hidden" attribute here after all?
    // https://developer.mozilla.org/en-US/docs/Web/HTML/Global_attributes/hidden
    this.drawer.removeAttribute("hidden");
  }
}

module.exports = {
  init
};
